# Code de Conduite du Contrat du Contributeur

## Notre engagement

Nous, en tant que membres, contributeurs et responsables, nous engageons à faire de la participation à notre
communauté une expérience sans harcèlement pour tous, indépendamment de l'âge, de la taille du corps,
de l'handicap visible ou invisible, de l'origine ethnique, des caractéristiques sexuelles, de l'identité et l'expression du genre,
du niveau d'expérience, de l'éducation, du statut socio-économique,
de la nationalité, de l'apparence personnelle, de la race, de la caste, de la couleur, de la religion, ou de l'identité et l'orientation sexuelle.

Nous nous engageons à agir et à interagir d'une manière qui contribue à une communauté ouverte, accueillante,
diversifiée, inclusive et saine.

## Nos normes

Des exemples de comportement qui contribuent à un environnement positif pour notre
communauté incluent :

- Démontrer l'empathie et la gentillesse envers les autres personnes
- Être respectueux des opinions, points de vue et expériences différents
- Donner et accepter gracieusement les retours constructifs
- Accepter la responsabilité et présenter des excuses à ceux affectés par nos erreurs,
  et apprendre de l'expérience
- Se concentrer sur ce qui est le mieux non seulement pour nous en tant qu'individus, mais pour l'ensemble de la
  communauté

Des exemples de comportement inacceptable incluent :

- L'utilisation de langage ou d'imagerie sexualisés, et l'attention ou les avances sexuelles de
  toute sorte
- Le trolling, les commentaires insultants ou péjoratifs, et les attaques personnelles ou politiques
- Le harcèlement public ou privé
- La publication d'informations privées d'autres personnes, telles qu'une adresse physique ou électronique,
  sans leur permission explicite
- Autre conduite qui pourrait raisonnablement être considérée comme inappropriée dans un
  cadre professionnel

## Responsabilités d'application

Les responsables de la communauté sont chargés de clarifier et d'appliquer nos normes de
comportement acceptable et prendront les mesures correctives appropriées et équitables
en réponse à tout comportement qu'ils jugeront inapproprié, menaçant, offensant,
ou nuisible.

Les responsables de la communauté ont le droit et la responsabilité de supprimer, modifier ou rejeter
des commentaires, des commits, du code, des modifications du wiki, des problèmes et d'autres contributions qui ne sont
pas alignées avec ce Code de Conduite, et communiqueront les raisons des décisions de modération lorsque approprié.

## Portée

Ce Code de Conduite s'applique dans tous les espaces communautaires, et s'applique aussi quand
un individu représente officiellement la communauté dans des espaces publics.
Des exemples de représentation de notre communauté incluent l'utilisation d'une adresse e-mail officielle,
la publication via un compte de média social officiel, ou agir en tant que représentant nommé
lors d'un événement en ligne ou hors ligne.

## Application

Les instances de comportement abusif, harcelant ou autrement inacceptable peuvent être
signalées aux responsables de la communauté responsables de l'application à
[jc.bianic@gmail.com](mailto:jc.bianic@gmail.com).
Toutes les plaintes seront examinées et enquêtées promptement et équitablement.

Tous les responsables de la communauté sont obligés de respecter la confidentialité et la sécurité du
signaleur de tout incident.

## Directives d'application

Les responsables de la communauté suivront ces Directives sur l'impact communautaire pour déterminer
les conséquences pour toute action qu'ils jugent en violation de ce Code de Conduite :

### 1. Correction

**Impact communautaire** : Utilisation de langage inapproprié ou autre comportement jugé
non professionnel ou indésirable dans la communauté.

**Conséquence** : Un avertissement privé et écrit des responsables de la communauté, fournissant
une clarté sur la nature de la violation et une explication de pourquoi le
comportement était inapproprié. Une excuse publique peut être demandée.

### 2. Avertissement

**Impact communautaire** : Une violation par un incident unique ou une série de
actions.

**Conséquence** : Un avertissement avec conséquences pour le comportement continu. Aucune
interaction avec les personnes impliquées, y compris l'interaction non sollicitée avec
ceux appliquant le Code de Conduite, pendant une période déterminée. Ceci
inclut d'éviter les interactions dans les espaces communautaires ainsi que sur les canaux externes
comme les réseaux sociaux. Violer ces conditions peut mener à un bannissement temporaire ou permanent.

### 3. Bannissement temporaire

**Impact communautaire** : Une violation grave des normes communautaires, y compris
un comportement inapproprié soutenu.

**Conséquence** : Un bannissement temporaire de toute sorte d'interaction ou communication publique
avec la communauté pendant une période déterminée. Aucune interaction publique ou
privée avec les personnes impliquées, y compris l'interaction non sollicitée avec
ceux appliquant le Code de Conduite, n'est autorisée pendant cette période.
Violer ces conditions peut mener à un bannissement permanent.

### 4. Bannissement permanent

**Impact communautaire** : Démonstration d'un schéma de violation des normes communautaires,
y compris un comportement inapproprié soutenu, le harcèlement d'un
individu, ou l'agression envers ou la disparagement de classes d'individus.

**Conséquence** : Un bannissement permanent de toute sorte d'interaction publique au sein de
la communauté.

## Attribution

Ce Code de Conduite est adapté du [Contrat du Contributeur][page d'accueil],
version 2.1, disponible à
[https://www.contributor-covenant.org/version/2/1/code_of_conduct.html][v2.1].

Les Directives sur l'impact communautaire ont été inspirées par
le [code de conduite d'application de Mozilla][mozilla coc].

Pour des réponses aux questions courantes sur ce code de conduite, voir la FAQ à
[https://www.contributor-covenant.org/faq][faq]. Les traductions sont disponibles à
[https://www.contributor-covenant.org/translations][translations].

[page d'accueil]: https://www.contributor-covenant.org
[v2.1]: https://www.contributor-covenant.org/version/2/1/code_of_conduct.html
[mozilla coc]: https://github.com/mozilla/diversity
[faq]: https://www.contributor-covenant.org/faq
[translations]: https://www.contributor-covenant.org/translations
